Gmls
====

GitHub Markdown Local Server.

I read great markdown wikis on github offline with it :).

Install
-------

```bash
$ [sudo] pip install gmls
```

Usage
------

```bash
$ gmls [-p PORT]
```

License
-------

MIT. Copyright hit9.
